(Lazyearth) Library OOP for workwith odc




For developers, the source code can be fully developed. Which is another project, because jupyter can't import def like it does. So the computer uses this method. And there are also many libraries that have been preserved.




P.S. This version is not complete. (Writing in a hurry) Just need to bring concept OOP to create library and then upload to Github and PyPI.For developers, the source code can be fully developed. Which is another project, The main reason that i create this because jupyter can't import def like the computer so uses this method. And there are also many libraries that have been preserved.
Develop by : Tun Kedsaro 


